import React, { useState } from 'react';
import { Search, BookOpen, Newspaper, GraduationCap, BrainCircuit, Code, Compass, Star } from 'lucide-react';
import { Card, CardContent, CardHeader, CardTitle } from '@/components/ui/card';

const TheAdaArcana = () => {
  const [activeCategory, setActiveCategory] = useState('all');
  
  const categories = [
    { id: 'chronicles', icon: Newspaper, label: 'The Chronicles' },
    { id: 'research', icon: GraduationCap, label: 'The Codex' },
    { id: 'philosophy', icon: BrainCircuit, label: 'The Symposium' },
    { id: 'innovations', icon: Code, label: 'The Observatory' }
  ];

  return (
    <div className="max-w-6xl mx-auto p-6 bg-gradient-to-b from-slate-50 to-white">
      <header className="text-center mb-12">
        <div className="mb-8">
          <div className="flex items-center justify-center mb-3">
            <Star className="text-purple-600 w-6 h-6 mr-2" />
            <h1 className="text-5xl font-bold bg-clip-text text-transparent bg-gradient-to-r from-purple-700 to-blue-600">
              The Ada Arcana
            </h1>
            <Star className="text-purple-600 w-6 h-6 ml-2" />
          </div>
          <p className="text-lg text-gray-600 font-serif italic">
            Illuminating the Frontiers of Artificial Intelligence
          </p>
        </div>
        
        <div className="max-w-2xl mx-auto relative">
          <input
            type="text"
            placeholder="Search the Archives..."
            className="w-full p-4 pl-12 rounded-lg border border-gray-200 focus:outline-none focus:ring-2 focus:ring-purple-500 bg-white/90 backdrop-blur-sm shadow-sm"
          />
          <Search className="absolute left-4 top-4 text-gray-400" />
        </div>
      </header>

      <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-4 mb-12">
        {categories.map(({ id, icon: Icon, label }) => (
          <Card 
            key={id}
            className={`cursor-pointer transition-all hover:bg-purple-50 ${
              activeCategory === id ? 'ring-2 ring-purple-500 bg-purple-50' : ''
            }`}
            onClick={() => setActiveCategory(id)}
          >
            <CardContent className="flex flex-col items-center justify-center p-6 text-center">
              <Icon className="mb-2 text-purple-600" />
              <span className="font-medium">{label}</span>
            </CardContent>
          </Card>
        ))}
      </div>

      <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6">
        {[1, 2, 3, 4, 5, 6].map((i) => (
          <Card key={i} className="hover:shadow-lg transition-shadow border-t-4 border-t-purple-500">
            <CardHeader>
              <div className="flex items-center text-sm text-purple-600 mb-2">
                <Compass className="w-4 h-4 mr-2" />
                <span>{categories[i % 4].label}</span>
              </div>
              <CardTitle className="text-lg font-serif">
                Featured Intelligence Archives
              </CardTitle>
            </CardHeader>
            <CardContent>
              <p className="text-gray-600 mb-4">
                Unveiling the latest discoveries and developments in the realm of artificial intelligence...
              </p>
              <div className="flex items-center text-sm text-gray-500">
                <time className="font-serif">October 26, 2024</time>
                <span className="mx-2">•</span>
                <span className="italic">5 min discourse</span>
              </div>
            </CardContent>
          </Card>
        ))}
      </div>
    </div>
  );
};

export default TheAdaArcana;
